@@ -35,7 +35,7 @@ Options:
 
 """
 
-__version__ = '0.0.16'
+__version__ = '0.0.17'
 
 
 from ConfigParser import NoSectionError, SafeConfigParser
@@ -55,6 +55,12 @@ except ImportError:
 
 class ClientError(Exception):
 
+  """Base client error class.
+
+  Stores the original traceback to be displayed in debug mode.
+
+  """
+
   def __init__(self, message):
     super(ClientError, self).__init__(message)
     self.traceback = format_exc()
@@ -64,6 +70,7 @@ class Client(object):
 
   """API client."""
 
+  #: Configuration default values
   config_defaults = {
     'user': getuser(),
     'host': '',
@@ -72,6 +79,7 @@ class Client(object):
     'default_folder': '.',
   }
 
+  #: Path to configuration file
   config_file = join(expanduser('~'), '.config', 'igloo', 'config')
 
   def __init__(self, profile, **kwargs):
@@ -79,10 +87,8 @@ class Client(object):
       profile,
       {k: v for k, v in kwargs.items() if not v is None}
     )
-    # filling in defaults
     for k, v in self.config_defaults.items():
       self.config.setdefault(k, v)
-    # folder
     self.config['folder'] = abspath(expanduser(join(
       self.config['root_folder'],
       self.config.get('folder', None) or self.config['default_folder'],
@@ -90,6 +96,7 @@ class Client(object):
 
   @contextmanager
   def get_sftp_client(self):
+    """Attempt to connect via SFTP to the remote host."""
     self.ssh = SSHClient()
     self.ssh.load_host_keys(join(expanduser('~'), '.ssh', 'known_hosts'))
     try:
@@ -117,6 +124,14 @@ class Client(object):
       self.ssh.close()
 
   def load_config(self, profile, options):
+    """Attempt to load configuration options.
+
+    :param profile: the profile to load
+    :param options: options specified on the command line, these will
+      override any profile level options.
+    :rtype: dict
+
+    """
     try:
       parser = SafeConfigParser()
       parser.read(self.config_file)
@@ -128,6 +143,7 @@ class Client(object):
         raise ClientError('config loading error')
 
   def get_callback(self):
+    """Callback function for ``sftp.put`` and ``sftp.get``."""
     def callback(transferred, total):
       progress = 100 * float(transferred) / total
       stdout.write('Progress: %.1f%%\r' % (progress, ))
@@ -135,6 +151,7 @@ class Client(object):
     return callback
 
   def upload(self, filename, track, stream):
+    """Attempt to upload a file the remote host."""
     with self.get_sftp_client() as sftp:
       if not stream:
         try:
@@ -160,6 +177,7 @@ class Client(object):
           remote_file.close()
 
   def download(self, filename, track, stream):
+    """Attempt to download a file from the remote host."""
     with self.get_sftp_client() as sftp:
       try:
         if not stream:
@@ -188,6 +206,7 @@ class Client(object):
         raise ClientError('remote file not found %r' % (filename, ))
 
   def remove(self, filename):
+    """Attempt to remove a file from the remote host."""
     with self.get_sftp_client() as sftp:
       try:
         sftp.unlink(filename)
@@ -195,6 +214,7 @@ class Client(object):
         raise ClientError('remote file not found %r' % (filename, ))
 
   def list(self):
+    """Attempt to list available files on the remote host."""
     with self.get_sftp_client() as sftp:
       return [
         filename
